GameCaptureSource

Struct GameCaptureSource 

pub struct GameCaptureSource { /* private fields */ }
Available on Windows only.
This struct is essentially a wrapper around an OBS source with additional functionality specific to the custom source.

It provides methods to create an updater and access source-specific signals.

Implementations

Source

impl GameCaptureSource

pub fn create_updater<'a>( &'a mut self, ) -> Result<GameCaptureSourceUpdater<'a>, ObsError>

Source

impl GameCaptureSource

pub fn inner_source(&self) -> &ObsSourceRef

pub fn inner_source_mut(&mut self) -> &mut ObsSourceRef

pub fn into_inner_source(self) -> ObsSourceRef

Consumes self and returns the inner ObsSourceRef

You can still update this source (if created by libobs-simple) and create an updater like so:

let updater = my_custom_source.create_updater()?;

let source = my_custom_source.into_inner_source();
let updater = source.create_updater::<MyCustomSourceUpdater>()?;