GameCaptureSourceUpdater

Struct GameCaptureSourceUpdater 

pub struct GameCaptureSourceUpdater<'a> { /* private fields */ }
Available on Windows only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.

Implementations

Source

impl<'a> GameCaptureSourceUpdater<'a>

pub fn set_capture_mode(self, capture_mode: ObsGameCaptureMode) -> Self

Sets the capture mode for the game capture source. Look at doc for ObsGameCaptureMode

pub fn set_window_raw<T: Into<ObsString> + Sync + Send>( self, window_raw: T, ) -> Self

Sets the window to capture.

Arguments
  • window - The window to capture, represented as ObsString. Must be in the format of an obs window id
Returns

The updated WindowCaptureSourceBuilder instance.

pub fn set_priority(self, priority: ObsWindowPriority) -> Self

Window Match Priority

pub fn set_sli_compatability(self, sli_compatability: bool) -> Self

SLI/Crossfire Capture Mode (Slow)

pub fn set_capture_cursor(self, capture_cursor: bool) -> Self

Whether the cursor should be captured

pub fn set_allow_transparency(self, allow_transparency: bool) -> Self

If transparency of windows should be allowed

pub fn set_premultiplied_alpha(self, premultiplied_alpha: bool) -> Self

Premultiplied Alpha

pub fn set_limit_framerate(self, limit_framerate: bool) -> Self

Limit capture framerate

pub fn set_capture_overlays(self, capture_overlays: bool) -> Self

Capture third party overlays (such as steam overlays)

pub fn set_anti_cheat_hook(self, anti_cheat_hook: bool) -> Self

Use anti-cheat compatibility hook

pub fn set_hook_rate(self, hook_rate: ObsHookRate) -> Self

Hook rate (Ranging from slow to fastest)

pub fn set_rgb10a2_space(self, rgb10a2_space: ObsGameCaptureRgbaSpace) -> Self

The color space to capture in

Source

impl<'a> GameCaptureSourceUpdater<'a>

pub fn set_capture_audio( self, capture_audio: bool, ) -> Result<Self, ObsSimpleError>